@@ -35,15 +35,15 @@
 #include <feel/feelalg/vector.hpp>
 #include <feel/feelalg/matrixsparse.hpp>
 
-#if defined(HAVE_PETSC_H)
+#if defined(FEELPP_HAS_PETSC_H)
 #include <feel/feelcore/application.hpp>
 
 
 extern "C"
 {
 #if defined(MPICH_NAME)
-#if !defined( MPICH_HAVE_MPI_WIN )
-#define MPICH_HAVE_MPI_WIN
+#if !defined( MPICH_FEELPP_HAS_MPI_WIN )
+#define MPICH_FEELPP_HAS_MPI_WIN
   struct MPI_Win {};
 #endif
 #endif
@@ -818,5 +818,5 @@ private :
 };
 
 } // Feel
-#endif /* HAVE_PETSC */
+#endif /* FEELPP_HAS_PETSC */
 #endif /* __VectorPetsc_H */
